import java.io.FileInputStream;
import java.io.FileOutputStream;

import com.cryptware.jdigitsign.DigitalSignerCryptoki;
import com.cryptware.jdigitsign.PDFSignatureGenerator;
import com.cryptware.jdigitsign.SignedDocument;
import com.cryptware.jdigitsign.SimpleCertificateSelector;

public class TestJDigitSign {

	public static void main(String[] args)
	{
		try
		{
			// searchs for a matching cryptoki based upon the ATR of the inserted smart card
			// mainly this line of code is dedicated to the italian qualified digital signature
			//String cryptokiPath = DigitalSigner.getMathingCryptokiPath();

			DigitalSignerCryptoki.setLicense("test", "34324234234");

			// get pkcs11 dll/so for the inserted smart card
			String module = DigitalSignerCryptoki.getMatchingCryptokiPath();

			// creates a new instance of DigitalSignature with the given pkcs11 module
			// you may specify your own PKCS#11 dll
			DigitalSignerCryptoki dsign = new DigitalSignerCryptoki(module);

			// open a new session with the slot 0
			dsign.openSession(0);

			// login
			dsign.login("12345678");

			// computes digital signature using the simple certificate selector
			SignedDocument sd = dsign.sign("some text to sign".getBytes(), new SimpleCertificateSelector(false), true, false, false);

			// verifies the signature
			int v = sd.verify();

			FileOutputStream fos = new FileOutputStream("C:\\test.p7m");
			fos.write(sd.toByteArray());

			System.out.println("verify simple " + v);

			String plaintext = new String(sd.getPlainText());

			System.out.println("plaintext " + plaintext);

			// computes digital signature using the qualified certificate selector
			sd = dsign.sign("some text to sign".getBytes(), new SimpleCertificateSelector(false), true, false, false);

			// verifies the signature
			v = sd.verify();

			System.out.println("verify qualified" + v);

			////////////////////////
			// PDF signature
			////////////////////////
			
			PDFSignatureGenerator pdfSignGen = new PDFSignatureGenerator();
			
			FileInputStream fins = new FileInputStream("document.pdf");
			pdfSignGen.load(fins);
			fins.close();				
						
			// Signature Rectangle
			int x = 100;
			int y = 100;
			int w = 200;
			int h = 200;
						
			// init the pdf signature
						
			pdfSignGen.init(1, x, y, w, h, "Signed by: Pico de Paperis", null, null, null, "Signature" + System.currentTimeMillis(), "ETSI.CAdES.detached", null);
	
			byte signedPDF[] = pdfSignGen.signPDF(dsign, new SimpleCertificateSelector(false), true, false, null);
			
			FileOutputStream fouts = new FileOutputStream("document.signed.pdf");
			fouts.write(signedPDF);
			fouts.close();
			
			dsign.logout();
			
			// closes the session
			dsign.closeSession();
		}
		catch(Exception ex)
		{
			ex.printStackTrace();
		}
	}

}